@@ -281,7 +281,7 @@ class Falyx:
 
     def _get_exit_command(self) -> Command:
         """Returns the back command for the menu."""
-        return Command(
+        exit_command = Command(
             key="X",
             description="Exit",
             action=Action("Exit", action=_noop),
@@ -293,6 +293,9 @@ class Falyx:
             program=self.program,
             help_text="Exit the program.",
         )
+        if exit_command.arg_parser:
+            exit_command.arg_parser.add_tldr_examples([("", "Exit the program.")])
+        return exit_command
 
     def _get_history_command(self) -> Command:
         """Returns the history command for the menu."""
@@ -337,6 +340,19 @@ class Falyx:
         parser.add_argument(
             "-l", "--last-result", action="store_true", help="Get the last result"
         )
+        parser.add_tldr_examples(
+            [
+                ("", "Show the full execution history."),
+                ("-n build", "Show history entries for the 'build' command."),
+                ("-s success", "Show only successful executions."),
+                ("-s error", "Show only failed executions."),
+                ("-i 3", "Show the history entry at index 3."),
+                ("-r 0", "Show the result or traceback for entry index 0."),
+                ("-l", "Show the last execution result."),
+                ("-c", "Clear the execution history."),
+            ]
+        )
+
         return Command(
             key="Y",
             description="History",
@@ -395,7 +411,7 @@ class Falyx:
                 self.console.print(f"[bold]tip:[/bold] {self.get_tip()}")
                 return None
         if key:
-            _, command, args, kwargs = await self.get_command(key)
+            _, command, args, kwargs = await self.get_command(key, from_help=True)
             if command and tldr and command.arg_parser:
                 command.arg_parser.render_tldr()
                 self.console.print(f"[bold]tip:[/bold] {self.get_tip()}")
@@ -486,6 +502,7 @@ class Falyx:
             aliases=["HELP", "?"],
             program=self.program,
             options_manager=self.options,
+            _is_help_command=True,
         )
         parser.add_argument(
             "-t",
@@ -506,8 +523,8 @@ class Falyx:
                 ("", "Show all commands."),
                 ("-k [COMMAND]", "Show detailed help for a specific command."),
                 ("-Tk [COMMAND]", "Show quick usage examples for a specific command."),
-                ("--tldr", "Show these quick usage examples."),
-                ("--tag [TAG]", "Show commands with the specified tag."),
+                ("-T", "Show these quick usage examples."),
+                ("-t [TAG]", "Show commands with the specified tag."),
             ]
         )
         return Command(
@@ -699,6 +716,8 @@ class Falyx:
             program=self.program,
             help_text=help_text,
         )
+        if self.exit_command.arg_parser:
+            self.exit_command.arg_parser.add_tldr_examples([("", help_text)])
 
     def add_submenu(
         self, key: str, description: str, submenu: Falyx, *, style: str = OneColors.CYAN
@@ -922,7 +941,7 @@ class Falyx:
         return False, input_str.strip()
 
     async def get_command(
-        self, raw_choices: str, from_validate=False
+        self, raw_choices: str, from_validate=False, from_help=False
     ) -> tuple[bool, Command | None, tuple, dict[str, Any]]:
         """
         Returns the selected command based on user input.
@@ -963,7 +982,7 @@ class Falyx:
                 logger.info("Command '%s' selected.", run_command.key)
             if is_preview:
                 return True, run_command, args, kwargs
-            elif self.is_cli_mode:
+            elif self.is_cli_mode or from_help:
                 return False, run_command, args, kwargs
             try:
                 args, kwargs = await run_command.parse_args(input_args, from_validate)
