@@ -3,6 +3,8 @@
 Defines reusable lifecycle hooks for Falyx Actions and Commands.
 
 This module includes:
+- `spinner_before_hook`: Automatically starts a spinner before an action runs.
+- `spinner_teardown_hook`: Stops and clears the spinner after the action completes.
 - `ResultReporter`: A success hook that displays a formatted result with duration.
 - `CircuitBreaker`: A failure-aware hook manager that prevents repeated execution
   after a configurable number of failures.
@@ -11,6 +13,7 @@ These hooks can be registered on `HookManager` instances via lifecycle stages
 (`before`, `on_error`, `after`, etc.) to enhance resiliency and observability.
 
 Intended for use with:
+- Actions that require user feedback during long-running operations.
 - Retryable or unstable actions
 - Interactive CLI feedback
 - Safety checks prior to execution
@@ -24,7 +27,6 @@ Example usage:
     reporter = ResultReporter()
     hooks.register(HookType.ON_SUCCESS, reporter.report)
 """
-
 import time
 from typing import Any, Callable
 
@@ -34,6 +36,38 @@ from falyx.logger import logger
 from falyx.themes import OneColors
 
 
+async def spinner_before_hook(context: ExecutionContext):
+    """Adds a spinner before the action starts."""
+    cmd = context.action
+    if cmd.options_manager is None:
+        return
+    sm = context.action.options_manager.spinners
+    if hasattr(cmd, "name"):
+        cmd_name = cmd.name
+    else:
+        cmd_name = cmd.key
+    await sm.add(
+        cmd_name,
+        cmd.spinner_message,
+        cmd.spinner_type,
+        cmd.spinner_style,
+        cmd.spinner_speed,
+    )
+
+
+async def spinner_teardown_hook(context: ExecutionContext):
+    """Removes the spinner after the action finishes (success or failure)."""
+    cmd = context.action
+    if cmd.options_manager is None:
+        return
+    if hasattr(cmd, "name"):
+        cmd_name = cmd.name
+    else:
+        cmd_name = cmd.key
+    sm = context.action.options_manager.spinners
+    await sm.remove(cmd_name)
+
+
 class ResultReporter:
     """Reports the success of an action."""
 
