@@ -1,3 +1,15 @@
+# Falyx CLI Framework — (c) 2025 rtj.dev LLC — MIT Licensed
+"""
+Generates a Rich table view of Falyx commands grouped by their tags.
+
+This module defines a utility function for rendering a custom CLI command
+table that organizes commands into groups based on their first tag. It is
+used to visually separate commands in interactive menus for better clarity
+and discoverability.
+
+Functions:
+- build_tagged_table(flx): Returns a `rich.Table` of commands grouped by tag.
+"""
 from collections import defaultdict
 
 from rich import box
@@ -9,7 +21,7 @@ from falyx.falyx import Falyx
 
 def build_tagged_table(flx: Falyx) -> Table:
     """Custom table builder that groups commands by tags."""
-    table = Table(title=flx.title, show_header=False, box=box.SIMPLE)
+    table = Table(title=flx.title, show_header=False, box=box.SIMPLE)  # type: ignore[arg-type]
 
     # Group commands by first tag
     grouped: dict[str, list[Command]] = defaultdict(list)
@@ -21,7 +33,7 @@ def build_tagged_table(flx: Falyx) -> Table:
     for group_name, commands in grouped.items():
         table.add_row(f"[bold underline]{group_name} Commands[/]")
         for cmd in commands:
-            table.add_row(f"[{cmd.key}] [{cmd.color}]{cmd.description}")
+            table.add_row(f"[{cmd.key}] [{cmd.style}]{cmd.description}")
         table.add_row("")
 
     # Add bottom row
